/*
    Copyright (C) 2020 Sebastian J. Wolf and other contributors

    This file is part of Fernschreiber.

    Fernschreiber is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Fernschreiber is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Fernschreiber. If not, see <http://www.gnu.org/licenses/>.
*/
import QtQuick 2.6
import Sailfish.Silica 1.0
import QtMultimedia 5.6
import "../components"
import "../components/messageContent"
import "../js/functions.js" as Functions
import "../js/debug.js" as Debug

Page {
    id: videoPage
    allowedOrientations: Orientation.All

    property var videoData;
    property alias videoType: myVideoComponent.videoType
    property alias isVideoNote: myVideoComponent.isVideoNote
    property var sourceMessage;

    property int videoWidth : videoData.width
    property int videoHeight : videoData.height
    property string videoUrl;

    property real imageSizeFactor : videoWidth / videoHeight;
    property real screenSizeFactor: videoPage.width / videoPage.height;
    property real sizingFactor    : imageSizeFactor >= screenSizeFactor ? videoPage.width / videoWidth : videoPage.height / videoHeight;

    Component.onCompleted: {
        updateVideoData();
    }

    function updateVideoData() {
        if (typeof videoData === "object") {
            if (videoData[videoType].local.is_downloading_completed) {
                videoPage.videoUrl = videoData[videoType].local.path;
            }
        }
    }

    SilicaFlickable {
        anchors.fill: parent

        PullDownMenu {
            id: videoPagePullDownMenu
            visible: (videoPage.videoUrl !== "")
            MenuItem {
                text: qsTr("Copy video to gallery")
                onClicked: {
                    tdLibWrapper.copyFileToDownloads(videoPage.videoUrl);
                }
            }
        }

        Connections {
            target: tdLibWrapper
            onFileUpdated: {
                if (fileId === videoPage.videoData[videoType].id) {
                    if (fileInformation.local.is_downloading_completed) {
                        videoPage.videoUrl = fileInformation.local.path;
                        videoPagePullDownMenu.visible = true;
                    }
                }
            }
            onCopyToDownloadsSuccessful: {
                appNotification.show(qsTr("Download of %1 successful.").arg(fileName), filePath);
            }

            onCopyToDownloadsError: {
                appNotification.show(qsTr("Download failed."));
            }
        }

        Item {
            width: videoPage.videoWidth * videoPage.sizingFactor
            height: videoPage.videoHeight * videoPage.sizingFactor
            anchors.centerIn: parent

            MessageVideo {
                id: myVideoComponent
                videoData: videoPage.videoData
                fullscreen: true
                onScreen: videoPage.status === PageStatus.Active
                rawMessage: sourceMessage
                anchors.fill: parent
            }
        }

    }
}

